import logging
from typing import Any, Optional

class JsonFormatter(logging.Formatter):
    format_dict: Any = ...
    default_json_formatter: Any = ...
    def __init__(self, **kwargs: Any) -> None: ...
    def format(self, record: Any): ...

def setup(level: str = ..., formatter_cls: Any = ..., boto_level: Optional[Any] = ..., **kwargs: Any) -> None: ...
