"""
*.pyi files are auto-generated with the following commands:

$> pip install mypy
$> stubgen ./crhelper -o .
"""
from crhelper.resource_helper import CfnResource as CfnResource, FAILED as FAILED, SUCCESS as SUCCESS
